Contribution
============

`Delorean <https://github.com/myusuf3/delorean>`_ is currently in active development and welcomes code improvements and bug fixes. For those of your interested in providing documentation to the lesser know parts would be equally awesome!

Pull down the source::

    $ git clone git@github.com:myusuf3/delorean.git

.. note::

   All code contributions should have adequate tests. `Delorean` has high test coverage we would like to keep this way.

Style
^^^^^

If you decide to contribute code please follow naming conventions and style guides the code currently complies too.

When in doubt, be safe, follow `PEP-8. <http://www.python.org/dev/peps/pep-0008/>`_

Documentation
^^^^^^^^^^^^^

Contributing to documentation is as simple as editing the specified file in the `docs` directory of the source. We welcome all code improvements.


We use Sphinx for building our documentation. That can be obtained `here <http://sphinx-doc.org/>`_
.

.. note::

    We provide easy to use `make` command that will build the docs and open a copy locally in your browser. Simply run the following command from the root directory::

    $ make doc


Reporting Issues
^^^^^^^^^^^^^^^^
This is most important of all, if there are issues please let us know. So we can improve `delorean`. If you don't report it, we probably wont fix it.

All issues should be reported on Github `here. <https://github.com/myusuf3/delorean/issues>`_